@@ -1,12 +1,12 @@
 # Building a Prod-Ready, Robust Shiny Application.
-# 
-# README: each step of the dev files is optional, and you don't have to 
-# fill every dev scripts before getting started. 
-# 01_start.R should be filled at start. 
+#
+# README: each step of the dev files is optional, and you don't have to
+# fill every dev scripts before getting started.
+# 01_start.R should be filled at start.
 # 02_dev.R should be used to keep track of your development during the project.
 # 03_deploy.R should be used once you need to deploy your app.
-# 
-# 
+#
+#
 ######################################
 #### CURRENT FILE: DEPLOY SCRIPT #####
 ######################################
@@ -20,8 +20,8 @@ rhub::check_for_cran()
 
 # Deploy
 
-## Local, CRAN or Package Manager ---- 
-## This will build a tar.gz that can be installed locally, 
+## Local, CRAN or Package Manager ----
+## This will build a tar.gz that can be installed locally,
 ## sent to CRAN, or to a package manager
 devtools::build()
 
@@ -33,10 +33,8 @@ golem::add_shinyserver_file()
 
 ## Docker ----
 ## If you want to deploy via a generic Dockerfile
-golem::add_dockerfile()
+golem::add_dockerfile_with_renv()
 
 ## If you want to deploy to ShinyProxy
-golem::add_dockerfile_shinyproxy()
+golem::add_dockerfile_with_renv_shinyproxy()
 
-## If you want to deploy to Heroku
-golem::add_dockerfile_heroku()
