@@ -1,7 +1,13 @@
 test_that("add_module", {
   with_dir(pkg, {
     remove_file("R/mod_test.R")
-    add_module("test", open = FALSE, pkg = pkg,  fct = "ftest", utils = "utest")
+    add_module(
+      "test",
+      open = FALSE,
+      pkg = pkg,
+      fct = "ftest",
+      utils = "utest"
+    )
     expect_true(file.exists("R/mod_test.R"))
     expect_true(file.exists("R/mod_test_fct_ftest.R"))
     expect_true(file.exists("R/mod_test_utils_utest.R"))
@@ -13,25 +19,30 @@ test_that("add_module", {
     expect_true(
       stringr::str_detect(output, "File created at R/mod_output.R")
     )
-    
+
     # Check content is not over-added
     lmod <- length(readLines("R/mod_output.R"))
     add_module("output", open = FALSE)
     expect_equal(
-      lmod, 
+      lmod,
       length(readLines("R/mod_output.R"))
     )
 
     remove_file("R/mod_test.R")
-    
-    # Test ext 
-    add_module("test2.R", open = FALSE, pkg = pkg,  fct = "ftest", utils = "utest")
+
+    # Test ext
+    add_module(
+      "test2.R",
+      open = FALSE,
+      pkg = pkg,
+      fct = "ftest",
+      utils = "utest"
+    )
     expect_true(file.exists("R/mod_test2.R"))
     expect_true(file.exists("R/mod_test2_fct_ftest.R"))
     expect_true(file.exists("R/mod_test2_utils_utest.R"))
     remove_file("R/mod_test2.R")
     remove_file("R/mod_test2_fct_ftest.R")
     remove_file("R/mod_test2_utils_utest.R")
-    
   })
 })
