@@ -1,4 +1,7 @@
 test_that("test extra sysreqs", {
+  skip_if_not_installed("renv")
+  skip_if_not_installed("dockerfiler", "0.2.0")
+   skip_if_not_installed("attachment", "0.2.5")
   with_dir(pkg, {
     for (fun in list(
       add_dockerfile,
